        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 34 <strong>control</strong><br>0,1,3,4,6,8,9,12,13,16,20,21,22,23,24,26,28,29,30,31,32,33,34,35,36,37,38,41,42,43,45,46,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 17 <br>2,5,7,10,11,14,15,17,18,19,25,27,39,40,44,47,48';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 34 <strong>control</strong><br>0,1,3,4,6,8,9,12,13,16,20,21,22,23,24,26,28,29,30,31,32,33,34,35,36,37,38,41,42,43,45,46,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 17 <br>2,5,7,10,11,14,15,17,18,19,25,27,39,40,44,47,48';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 34 <strong>control</strong><br>0,1,3,4,6,8,9,12,13,16,20,21,22,23,24,26,28,29,30,31,32,33,34,35,36,37,38,41,42,43,45,46,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 17 <br>2,5,7,10,11,14,15,17,18,19,25,27,39,40,44,47,48';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 34 <strong>control</strong><br>0,1,3,4,6,8,9,12,13,16,20,21,22,23,24,26,28,29,30,31,32,33,34,35,36,37,38,41,42,43,45,46,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 17 <br>2,5,7,10,11,14,15,17,18,19,25,27,39,40,44,47,48';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 34 <strong>control</strong><br>0,1,3,4,6,8,9,12,13,16,20,21,22,23,24,26,28,29,30,31,32,33,34,35,36,37,38,41,42,43,45,46,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 17 <br>2,5,7,10,11,14,15,17,18,19,25,27,39,40,44,47,48';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 34 <strong>control</strong><br>0,1,3,4,6,8,9,12,13,16,20,21,22,23,24,26,28,29,30,31,32,33,34,35,36,37,38,41,42,43,45,46,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 17 <br>2,5,7,10,11,14,15,17,18,19,25,27,39,40,44,47,48';}
}
